/*
 * Copyright (c) 2008-present Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global Sonatype, Nexus, Ext*/

// FIXME: Re-write as NX.define singleton=true

define('Nexus/clm', [
  'Nexus/config',
  'Nexus/messages',
  'Nexus/siesta'
], function () {

  Ext.namespace('Nexus.clm');

  /**
   * Base identifier for all plugins bits.
   *
   * @type {String}
   * @static
   */
  Nexus.clm.ID = 'nx-clm';

  /**
   * Title for various bits.
   *
   * @type {String}
   * @static
   */
  Nexus.clm.TITLE = 'IQ Server Connection';

  /**
   * Title for dashboard.
   *
   * @type {String}
   * @static
   */
  Nexus.clm.TITLE_DASHBOARD = 'IQ Server Dashboard';

  /**
   * Title for the tab.
   * @type {string}
   */
  Nexus.clm.TAB_TITLE = "IQ Server Connection";

  /**
   * ID for the tab.
   * @type {string}
   */
  Nexus.clm.TAB_ID = "clm";

  /**
   * Show a user-token transient message.
   *
   * @param message
   * @static
   */
  Nexus.clm.showMessage = function (message) {
    Nexus.messages.show(Nexus.clm.TITLE, message);
  };

  /**
   * Returns the path to a clm REST resource.
   *
   * @param path
   * @return {String}
   * @static
   */
  Nexus.clm.resourcePath = Nexus.siesta.basePath + '/clm';
  
  Nexus.clm.testConnectionPath = Nexus.clm.resourcePath + '/testConnection';
  
  Nexus.clm.componentDetailContentResourcePath = Nexus.siesta.basePath + '/healthcheck/clm/assets/version-graph/rm/nexus';

  Nexus.clm.firewallResourcePath = Nexus.clm.resourcePath + '/firewall';

  Nexus.clm.firewallSummaryResourcePath = Nexus.clm.firewallResourcePath + '/summary';

  Nexus.clm.chickletTemplate = NX.create('Ext.XTemplate',
        '<tpl if="criticalCount &gt; 0">',
          '<div class="nx-clm-chiclet-small critical">{criticalCount:htmlEncode}</div>',
        '</tpl>',
        '<tpl if="severeCount &gt; 0">',
          '<div class="nx-clm-chiclet-small severe">{severeCount:htmlEncode}</div>',
        '</tpl>',
        '<tpl if="moderateCount &gt; 0">',
          '<div class="nx-clm-chiclet-small moderate">{moderateCount:htmlEncode}</div>',
        '</tpl>',
        '<tpl if="(criticalCount + severeCount + moderateCount) == 0">No violations</tpl>',
        '<tpl if="detailedReport">',
          '<span class="view-report-link-span">',
            '<a href="{detailedReport:htmlEncode}" target="_blank" class="view-report-link">View Full Report</a>',
          '</span>',
        '</tpl>',
        {
          compiled : true
        }
  );
});
